@@ -528,11 +528,7 @@ class H2OTypeConverters(object):
         if jdf is None:
             return None
         elif isinstance(jdf, JavaObject):
-            session = SparkSession.builder.getOrCreate()
-            if hasattr(session, '_wrapped'):
-                sqlContext = session._wrapped
-            else:
-                sqlContext = session  # Spark 3.3+ utilizes SparkSession instead of SQLContext
+            sqlContext = SparkSession.builder.getOrCreate()._wrapped
             return DataFrame(jdf, sqlContext)
         else:
             raise TypeError("Invalid type.")
