@@ -6,14 +6,6 @@
 """Shared utilities used by various classes, all placed here to avoid circular imports.
 
 This file INTENTIONALLY has NO module dependencies!
-
-TODO: clean up this file that turned into a waste bin over the years:
-- split this into more specific modules.
-- utility modules should have a specific name to limit the scope of the garbage we put in (like waste sorting).
-- utility modules should if possible be placed under appropriate parent module 
-  (e.g. model/mojo related utility functions should go under h2o.model)
-- utility functions used ONLY in tests should go to test utilities! no reason to export those to end users!
-- same for model_utils.py nearby
 """
 from __future__ import absolute_import, division, print_function, unicode_literals
 from .compatibility import *  # NOQA
@@ -44,11 +36,6 @@ _id_allowed_characters = set("ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwx
 __all__ = ('mojo_predict_csv', 'mojo_predict_pandas')
 
 
-class List(list):
-    """a list accepting attributes"""
-    pass
-
-
 def _py_tmp_key(append):
     global _id_ctr
     _id_ctr += 1
@@ -362,6 +349,16 @@ def get_human_readable_time(time_ms):
     return res.strip()
 
 
+def print2(msg, flush=False, end="\n"):
+    """
+    This function exists here ONLY because Sphinx.ext.autodoc gets into a bad state when seeing the print()
+    function. When in that state, autodoc doesn't display any errors or warnings, but instead completely
+    ignores the "bysource" member-order option.
+    """
+    print(msg, end=end)
+    if flush: sys.stdout.flush()
+
+
 def normalize_slice(s, total):
     """
     Return a "canonical" version of slice ``s``.
@@ -401,7 +398,7 @@ h2o_predictor_class = "hex.genmodel.tools.PredictCsv"
 
 
 def mojo_predict_pandas(dataframe, mojo_zip_path, genmodel_jar_path=None, classpath=None, java_options=None, 
-                        verbose=False, setInvNumNA=False, predict_contributions=False, predict_calibrated=False):
+                        verbose=False, setInvNumNA=False, predict_contributions=False):
     """
     MOJO scoring function to take a Pandas frame and use MOJO model as zip file to score.
 
@@ -415,7 +412,6 @@ def mojo_predict_pandas(dataframe, mojo_zip_path, genmodel_jar_path=None, classp
     :param verbose: Optional, if True, then additional debug information will be printed. False by default.
     :param predict_contributions: if True, then return prediction contributions instead of regular predictions 
         (only for tree-based models).
-    :param predict_calibrated: if true, then return calibrated probabilities in addition to the predicted probabilities.
     :return: Pandas frame with predictions
     """
     tmp_dir = tempfile.mkdtemp()
@@ -430,15 +426,14 @@ def mojo_predict_pandas(dataframe, mojo_zip_path, genmodel_jar_path=None, classp
         mojo_predict_csv(input_csv_path=input_csv_path, mojo_zip_path=mojo_zip_path,
                          output_csv_path=prediction_csv_path, genmodel_jar_path=genmodel_jar_path,
                          classpath=classpath, java_options=java_options, verbose=verbose, setInvNumNA=setInvNumNA,
-                         predict_contributions=predict_contributions, predict_calibrated=predict_calibrated)
+                         predict_contributions=predict_contributions)
         return pandas.read_csv(prediction_csv_path)
     finally:
         shutil.rmtree(tmp_dir)
 
 
 def mojo_predict_csv(input_csv_path, mojo_zip_path, output_csv_path=None, genmodel_jar_path=None, classpath=None, 
-                     java_options=None, verbose=False, setInvNumNA=False, 
-                     predict_contributions=False, predict_calibrated=False,
+                     java_options=None, verbose=False, setInvNumNA=False, predict_contributions=False, 
                      extra_cmd_args=None):
     """
     MOJO scoring function to take a CSV file and use MOJO model as zip file to score.
@@ -455,7 +450,6 @@ def mojo_predict_csv(input_csv_path, mojo_zip_path, output_csv_path=None, genmod
     :param verbose: Optional, if True, then additional debug information will be printed. False by default.
     :param predict_contributions: if True, then return prediction contributions instead of regular predictions 
         (only for tree-based models).
-    :param predict_calibrated: if true, then return calibrated probabilities in addition to the predicted probabilities.
     :param extra_cmd_args: Optional, a list of additional arguments to append to genmodel.jar's command line. 
     :return: List of computed predictions
     """
@@ -521,9 +515,6 @@ def mojo_predict_csv(input_csv_path, mojo_zip_path, output_csv_path=None, genmod
     if predict_contributions:
         cmd.append('--predictContributions')
 
-    if predict_calibrated:
-        cmd.append('--predictCalibrated')
-
     if extra_cmd_args:
         cmd += extra_cmd_args
 
